paralelocs_qlikapi.api package — Paralelo CS Qlik API SDK for Python 0.2.5 documentation

# paralelocs_qlikapi.api package

## paralelocs_qlikapi.api.api module

class `paralelocs_qlikapi.api.api.` `QlikAPI`(hostname='localhost', sslfile=None, sslfile_key=None, verify=True)

  Bases: `object`

  `Hello` instance. :param name: A string to assign to the name instance attribute.

## paralelocs_qlikapi.api.auth module

class `paralelocs_qlikapi.api.auth.` `QlikAuth`(hostname='localhost', sslfile=None, sslfile_key=None, verify=True)

  Bases: `object`

  Classe base para criação dos Headers exigidos pela API do QLIK